##  Configuration Changelog
On the Audit Log tab of the fact sheet configuration page, you can view a comprehensive record of all changes made to the fact sheet configuration.
Additionally, you can retrieve the history of changes made to the meta model through the Pathfinder REST API by sending a GET request to the following endpoint:

```
https://{SUBDOMAIN}.leanix.net/services/pathfinder/v1/models/metaModel/actionBatches
```



